@@ -5,30 +5,59 @@
 #added { and } before and after each variable name to allow siunitx to work with stars
 #added the absolute value in the big comparison for cor2latex and df2latex
 #added the ability to round numbers even though other columns are character  (01/24/20)
+#modified May 29, 2021 to addthe ability to do long tables
 #
+
 "df2latex" <- 
 function(x,digits=2,rowlabels=TRUE,apa=TRUE,short.names=TRUE,
 font.size ="scriptsize",big.mark=NULL, drop.na=TRUE, heading="A table from the psych package in R",
-caption="df2latex",label="default",char=FALSE,stars=FALSE,silent=FALSE,file=NULL,append=FALSE,cut=0,big=.0,abbrev=NULL) {
+caption="df2latex",label="default",char=FALSE,stars=FALSE,silent=FALSE,file=NULL,append=FALSE,cut=0,big=.0,abbrev=NULL,long=FALSE) {
 #first set up the table
 if(is.null(abbrev)) abbrev<- digits + 3
  nvar <- dim(x)[2]
  rname<- rownames(x)
  tempx <- x
 comment <- paste("%", match.call())
+if(long) {
+ header <- paste0("\\begin{center}
+ \\begin{",font.size,"} 
+ \\begin{longtable}")
+header <- c(header,"{l",rep("r",(nvar)),"}\n")
+header <- c(header,paste0("
+\\caption{",caption,"}
+\\endfirsthead
+\\multicolumn{",nvar+1,"}{c}
+{{\\bfseries \\tablename\\ \\thetable{} -- continued from previous page}} \\\\
+\\endhead 
+\\hline \\multicolumn{",nvar+1,"}{|c|}{{Continued on next page}} \\\\ 
+\\hline
+\\endfoot
+\\hline \\hline
+\\endlastfoot
+"))
+ #this wraps up the long table
+footer <- paste0("\\end{longtable}   
+\\end{",font.size,"}
+\\end{center}")
+} else {
 header <- paste("\\begin{table}[htpb]",
 "\\caption{",caption,"}
 \\begin{center}
 \\begin{",font.size,"} 
 \\begin{tabular}",sep="")
-if(stars) {if(rowlabels) {
+
+
+ if(stars) {if(rowlabels) {
                header <- c(header,"{l",rep("S",(nvar)),"}\n")} else {header <- c(header,"{",rep("S",(nvar+1)),"}\n")}  } else {
               if(rowlabels) { header <- c(header,"{l",rep("r",(nvar)),"}\n")} else {header <- c(header,"{",rep("r",(nvar+1)),"}\n")}
                }
+
 if(apa) {header <- c(header,
 "\\multicolumn{",nvar,"}{l}{",heading,"}",
 '\\cr \n \\hline ')
-footer <- paste(" \\hline ")}  else {footer <- NULL}
+footer <- paste(" \\hline ")} else {footer <- NULL}
+ 
+
 if (stars){
       footer <- paste(" \\hline 
                       \n \\multicolumn{7}{l}{\\scriptsize{\\emph{Note: }\\textsuperscript{***}$p<.001$; 
@@ -45,8 +74,10 @@ footer <- paste(footer,"
 
 ",sep=""
 )
-
+#end of not long 
+}
 #now put the data into it
+if(big) all.x <- x  #we need to keep the original format of the data to do the big operation
 if(!char) {if(!is.null(digits)) {if(is.numeric(x) ) {x <- round(x,digits=digits)} else {for(i in 1:ncol(x)) {if (is.numeric(x[,i])) x[,i] <- round(x[,i],2)} }
        if(cut > 0) x[abs(x) < cut] <- NA }
       }
@@ -60,12 +91,15 @@ if(!char) {if(!is.null(digits)) {if(is.numeric(x) ) {x <- round(x,digits=digits)
 if(apa)  {allnames <- c("Variable  &  ",names1,lastname," \\hline \n")} else {if(rowlabels) {allnames <- c("  &  ",names1,lastname,"\\cr \n")} else {
              allnames <- c(names1,lastname,"\\cr \n")}}
 if(!char) {if(is.null(big.mark)) { x <- format(x,drop0trailing=FALSE)
-     if(big > 0) {x[abs(tempx ) > big] <- paste0("\\bf{",x[abs(tempx) > big],"}") }
+     if(big > 0) {
+
+     for(i in 1:ncol(x)) {if (is.numeric(all.x[,i])) x[abs(all.x[,i] ) > big,i] <- paste0("\\bf{",x[abs(all.x[,i]) > big,i],"}") }}
+    # if(is.numeric(tempx)) x[abs(tempx ) > big] <- paste0("\\bf{",x[abs(tempx) > big],"}") }
      
      
      } else   #to keep the digits the same
                       {x <- prettyNum(x,big.mark=",",drop0trailing=FALSE)} 
-   }  else {if(big > 0) { x[!is.na(abs(as.numeric(x))>big) & abs(as.numeric(x))>big ] <-    paste0("\\bf{", x[!is.na(abs(as.numeric(x))>big) & abs(as.numeric(x))>big ],"}")  } }
+   }  else {if(big > 0) { x[!is.na(abs(as.numeric(all.x))>big) & abs(as.numeric(all.x))>big ] <-    paste0("\\bf{", x[!is.na(abs(as.numeric(all.x))>big) & abs(as.numeric(all.x))>big ],"}")  } }
    # x[!is.na(abs(as.numeric(x)) > big)]<-  paste0("\\bf{", x[!is.na(abs(as.numeric(x)) > big)],"}")  }}
  value <- apply(x,1,paste,collapse="  &  ") #insert & between columns
 
@@ -84,8 +118,7 @@ result <- c(header,allnames,values,footer)
 if(!is.null(file)) write.table(result,file=file,row.names=FALSE,col.names=FALSE,quote=FALSE,append=append)
 
 invisible(result)
- }
- 
+ }  #end df2latex
  
  
  cor2latex <- function (x, use = "pairwise", method="pearson", adjust="holm", stars = FALSE, digits=2, rowlabels = TRUE, lower = TRUE, apa = TRUE, 
